#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/10/15 0015
# @Author  : justin.郑 3907721@qq.com
# @File    : movie.py
# @Desc    : 影视数据
# EBOT艺恩票房智库 https://www.endata.com.cn

import json
import os
import pandas as pd
import requests
import execjs
from gopup.movie.cons import headers
from gopup.utils.date_utils import today, day_last_date


def realtime_boxoffice():
    """
    获取实时电影票房数据
    数据来源：EBOT艺恩票房智库 https://www.endata.com.cn/BoxOffice
    :return:
        DataFrame
              BoxOffice     实时票房（万）
              Irank         排名
              MovieName     影片名
              boxPer        票房占比 （%）
              movieDay      上映天数
              sumBoxOffice  累计票房（万）
              default_url   影片海报
    """
    try:
        url = "https://www.endata.com.cn/API/GetData.ashx"
        data = {
            "tdate": today(),
            "MethodName": "BoxOffice_GetHourBoxOffice"
        }
        r = requests.post(url=url, data=data, headers=headers)
        js = get_js('webDES.js')

        docjs = execjs.compile(js)
        res = docjs.call("webInstace.shell", r.text)
        res_dict = json.loads(res)

        if res_dict['Status'] == 1:
            tmp = res_dict['Data']['Table1']
            res_pd = pd.DataFrame(tmp)
            res_pd = res_pd.drop(columns=['moblie_url', 'larger_url', 'mId', 'MovieImg'])
        return res_pd
    except Exception as e:
        return None


def day_boxoffice(date=None):
    """
    获取单日电影票房数据
    数据来源：EBOT艺恩票房智库 https://www.endata.com.cn/BoxOffice
    :param date: 日期
    :return:
        DataFrame
              Irank         排名
              MovieName     影片名
              BoxOffice     单日票房(万)
              BoxOffice_Up  环比变化
              SumBoxOffice  累计票房（万）
              default_url   影片海报
              AvgPrice      平均票价
              AvpPeoPle     场均人次
              RapIndex      口碑指数
              MovieDay      上映天数

    """
    try:
        if date == None:
            edate = today()
        else:
            edate = date
        sdate = day_last_date(edate, days=1)
        url = "https://www.endata.com.cn/API/GetData.ashx"
        data = {
            "sdate": sdate,
            "edate": edate,
            "MethodName": "BoxOffice_GetDayBoxOffice"
        }
        r = requests.post(url=url, data=data, headers=headers)
        js = get_js('webDES.js')

        docjs = execjs.compile(js)
        res = docjs.call("webInstace.shell", r.text)
        res_dict = json.loads(res)

        if res_dict['Status'] == 1:
            tmp = res_dict['Data']['Table']
            res_pd = pd.DataFrame(tmp)
            res_pd = res_pd.drop(columns=['MovieImg', 'moblie_url', 'larger_url', 'MovieID', 'Director', 'BoxOffice1', 'IRank_pro', 'RapIndex'])
        return res_pd
    except Exception as e:
        return None


def day_cinema(date=None):
    """
    获取单日影院票房
    :param date:
    :return:
        DataFrame
              RowNum         排名
              CinemaName     影院名称
              TodayBox       单日票房(元)
              TodayShowCount 单日场次
              AvgPeople      场均人次
              price          场均票价(元)
              Attendance     上座率
    """
    try:
        url = "https://www.endata.com.cn/API/GetData.ashx"
        data = {
            "date": date,
            "rowNum1": 1,
            "rowNum2": 100,
            "MethodName": "BoxOffice_GetCinemaDayBoxOffice"
        }
        r = requests.post(url=url, data=data, headers=headers)
        js = get_js('webDES.js')

        docjs = execjs.compile(js)
        res = docjs.call("webInstace.shell", r.text)
        res_dict = json.loads(res)

        if res_dict['Status'] == 1:
            tmp = res_dict['Data']['Table']
            res_pd = pd.DataFrame(tmp)
            res_pd = res_pd.drop(
                columns=['CinemaID', 'TodayAudienceCount', 'TodayOfferSeat'])
        return res_pd
    except Exception as e:
        return None


def realtime_tv():
    """
    获取实时电视剧播映指数
    数据来源：EBOT艺恩票房智库 https://www.endata.com.cn/BoxOffice/Video/index.html
    :return:
        DataFrame
              TvName        名称
              Irank         排名
              Genres        类型
              PlayIndex     播映指数
              MediaHot      媒体热度
              UserHot       用户热度
              AnswerHot     好评度
              PlayHot       观看度
              date          日期
    """
    try:
        url = "https://www.endata.com.cn/API/GetData.ashx"
        data = {
            "tvType": 2,
            "MethodName": "BoxOffice_GetTvData_PlayIndexRank"
        }
        r = requests.post(url=url, data=data, headers=headers)
        js = get_js('webDES.js')

        docjs = execjs.compile(js)
        res = docjs.call("webInstace.shell", r.text)
        res_dict = json.loads(res)

        if res_dict['Status'] == 1:
            tmp = res_dict['Data']['Table']
            res_pd = pd.DataFrame(tmp)
            res_pd['date'] = res_dict['Data']['Table1'][0]['MaxDate']
        return res_pd
    except Exception as e:
        return None


def realtime_show():
    """
    获取实时综艺播映指数
    数据来源：EBOT艺恩票房智库 https://www.endata.com.cn/BoxOffice/Video/index.html
    :return:
        DataFrame
              TvName        名称
              Irank         排名
              Genres        类型
              PlayIndex     播映指数
              MediaHot      媒体热度
              UserHot       用户热度
              AnswerHot     好评度
              PlayHot       观看度
              date          日期
    """
    try:
        url = "https://www.endata.com.cn/API/GetData.ashx"
        data = {
            "tvType": 8,
            "MethodName": "BoxOffice_GetTvData_PlayIndexRank"
        }
        r = requests.post(url=url, data=data, headers=headers)
        js = get_js('webDES.js')

        docjs = execjs.compile(js)
        res = docjs.call("webInstace.shell", r.text)
        res_dict = json.loads(res)

        if res_dict['Status'] == 1:
            tmp = res_dict['Data']['Table']
            res_pd = pd.DataFrame(tmp)
            res_pd['date'] = res_dict['Data']['Table1'][0]['MaxDate']
        return res_pd
    except Exception as e:
        return None


def realtime_artist():
    """
    获取艺人商业价值
    数据来源：EBOT艺恩票房智库 https://www.endata.com.cn/BoxOffice/Marketing/Artist/business.html
    :return:
        DataFrame
              StarBaseName  艺人
              Irank         排名
              BusinessValueIndex_L1  商业价值
              MajorHotIndex_L2       专业热度
              FocusHotIndex_L2       关注热度
              PredictHotIndex_L2     预测热度
              ReputationIndex_L3     美誉度
    """
    try:
        url = "https://www.endata.com.cn/API/GetData.ashx"
        data = {
            "Order": "BusinessValueIndex_L1",
            "OrderType": "DESC",
            "PageIndex": 1,
            "PageSize": 100,
            "MethodName": "Data_GetList_Star"
        }
        r = requests.post(url=url, data=data, headers=headers)
        js = get_js('webDES.js')

        docjs = execjs.compile(js)
        res = docjs.call("webInstace.shell", r.text)
        res_dict = json.loads(res)

        if res_dict['Status'] == 1:
            tmp = res_dict['Data']['Table']
            res_pd = pd.DataFrame(tmp)
            res_pd = res_pd.drop(
                columns=['StarBaseID'])
        return res_pd
    except Exception as e:
        return None


def realtime_artist_flow():
    """
    获取艺人流量价值
    数据来源：EBOT艺恩票房智库 https://www.endata.com.cn/BoxOffice/Marketing/Artist/business.html
    :return:
        DataFrame
              StarBaseName  艺人
              Irank         排名
              FlowValueIndex_L1      流量价值
              MajorHotIndex_L2       专业热度
              FocusHotIndex_L2       关注热度
              PredictHotIndex_L2     预测热度
              TakeGoodsIndex_L2      带货力
    """
    try:
        url = "https://www.endata.com.cn/API/GetData.ashx"
        data = {
            "Order": "FlowValueIndex_L1",
            "OrderType": "DESC",
            "PageIndex": 1,
            "PageSize": 100,
            "MethodName": "Data_GetList_Star"
        }
        r = requests.post(url=url, data=data, headers=headers)
        js = get_js('webDES.js')

        docjs = execjs.compile(js)
        res = docjs.call("webInstace.shell", r.text)
        res_dict = json.loads(res)

        if res_dict['Status'] == 1:
            tmp = res_dict['Data']['Table']
            res_pd = pd.DataFrame(tmp)
            res_pd = res_pd.drop(
                columns=['StarBaseID', 'ReputationIndex_L3', 'BusinessValueIndex_L1'])
        return res_pd
    except Exception as e:
        return None


def get_js(js_url):
    js_url = "http://www.gopup.cn/static/lib/webDES.js"
    r = requests.get(url=js_url)
    return r.text


def _get_js_path(name, module_file):
    """
    获取 JS 文件的路径(从模块所在目录查找)
    :param name: 文件名
    :param module_file: filename
    :return: str json_file_path
    """
    module_folder = os.path.abspath(os.path.dirname(os.path.dirname(module_file)))
    module_json_path = os.path.join(module_folder, "movie", name)
    return module_json_path


if __name__ == "__main__":
    # "Python运行execjs中出现编码问题: https://www.jianshu.com/p/df0000013254"
    # tmp = get_js("webDES.js")
    tmp = realtime_boxoffice()
    print(tmp)




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/3/27 0027
# @Author  : justin.郑 3907721@qq.com
# @File    : cons.py
# @Desc    : 配置文件

P_TYPE = {'http': 'http://', 'ftp': 'ftp://'}

MACRO_TYPE = ['nation','price','fininfo']

MACRO_URL = '%smoney.finance.%s/mac/api/jsonp.php/SINAREMOTECALLCALLBACK%s/MacPage_Service.get_pagedata?cate=%s&event=%s&from=0&num=%s&condition=&_=%s'

DOMAINS = {'sina': 'sina.com.cn', 'sinahq': 'sinajs.cn',
           'ifeng': 'ifeng.com', 'sf': 'finance.sina.com.cn',
           'vsf': 'vip.stock.finance.sina.com.cn',
           'idx': 'www.csindex.com.cn', '163': 'money.163.com',
           'em': 'eastmoney.com', 'sseq': 'query.sse.com.cn',
           'sse': 'www.sse.com.cn', 'szse': 'www.szse.cn',
           'oss': 'file.tushare.org', 'idxip':'115.29.204.48',
           'shibor': 'www.shibor.org', 'mbox':'www.cbooo.cn',
           'tt': 'gtimg.cn', 'gw': 'gw.com.cn',
           'v500': 'value500.com', 'sstar': 'stock.stockstar.com',
           'dfcf': 'nufm.dfcfw.com'}

PAGES = {'fd': 'index.phtml', 'dl': 'downxls.php', 'jv': 'json_v2.php',
         'cpt': 'newFLJK.php', 'ids': 'newSinaHy.php', 'lnews': 'rollnews_ch_out_interface.php',
         'ntinfo': 'vCB_BulletinGather.php', 'hs300b': '000300cons.xls',
         'hs300w': '000300closeweight.xls','sz50b': '000016cons.xls',
         'dp': 'all_fpya.php', '163dp':'fpyg.html',
         'emxsg': 'JS.aspx', '163fh':'jjcgph.php',
         'newstock': 'vRPD_NewStockIssue.php', 'zz500b': '000905cons.xls',
         'zz500wt': '000905closeweight.xls',
         't_ticks': 'vMS_tradedetail.php', 'dw': 'downLoad.html',
         'qmd': 'queryMargin.do', 'szsefc': 'ShowReport.szse',
         'ssecq': 'commonQuery.do', 'sinadd': 'cn_bill_download.php', 'ids_sw':'SwHy.php',
         'idx': 'index.php', 'index': 'index.html'}

SHIBOR_TYPE ={'Shibor': 'Shibor数据', 'Quote': '报价数据', 'Tendency': 'Shibor均值数据',
              'LPR': 'LPR数据', 'LPR_Tendency': 'LPR均值数据'}

GDP_YEAR_COLS = ['year','gdp','pc_gdp','gnp','pi','si','industry','cons_industry','ti','trans_industry','lbdy']
GDP_QUARTER_COLS = ['quarter','gdp','gdp_yoy','pi','pi_yoy','si','si_yoy','ti','ti_yoy']
GDP_FOR_COLS = ['year','end_for','for_rate','asset_for','asset_rate','goods_for','goods_rate']
GDP_PULL_COLS = ['year','gdp_yoy','pi','si','industry','ti']
GDP_CONTRIB_COLS = ['year','gdp_yoy','pi','si','industry','ti']
CPI_COLS = ['month','cpi']
PPI_COLS = ['month','ppiip','ppi','qm','rmi','pi','cg','food','clothing','roeu','dcg']
DEPOSIT_COLS = ['date','deposit_type','rate']
LOAN_COLS = ['date','loan_type','rate']
RRR_COLS = ['date','before','now','changed']
MONEY_SUPPLY_COLS = ['month','m2','m2_yoy','m1','m1_yoy','m0','m0_yoy','cd','cd_yoy','qm','qm_yoy','ftd','ftd_yoy','sd','sd_yoy','rests','rests_yoy']
MONEY_SUPPLY_BLA_COLS = ['year','m2','m1','m0','cd','qm','ftd','sd','rests']
GOLD_AND_FOREIGN_CURRENCY_RESERVES = ['month','gold','foreign_reserves']

SHIBOR_DATA_URL = '%s%s/shibor/web/html/%s?nameNew=Historical_%s_Data_%s.xls&downLoadPath=data&nameOld=%s%s.xls&shiborSrc=http://www.shibor.org/shibor/'

LPR_DATA_URL = 'http://www.chinamoney.com.cn/ags/ms/cm-u-bk-currency/LprHis'

SHIBOR_COLS = ['date', 'ON', '1W', '2W', '1M', '3M', '6M', '9M', '1Y']
SHIBOR_Q_COLS = ['date', 'bank', 'ON', '1W', '2W', '1M', '3M', '6M', '9M', '1Y']
SHIBOR_MA_COLS = ['date', 'ON_5', 'ON_10', 'ON_20', '1W_5', '1W_10', '1W_20','2W_5', '2W_10', '2W_20',
                  '1M_5', '1M_10', '1M_20', '3M_5', '3M_10', '3M_20', '6M_5', '6M_10', '6M_20',
                  '9M_5', '9M_10', '9M_20','1Y_5', '1Y_10', '1Y_20']


def random(n=13):
    from random import randint
    start = 10**(n-1)
    end = (10**n)-1
    return str(randint(start, end))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2021/2/20 0020
# @Author  : justin.郑 3907721@qq.com
# @File    : hot_list.py
# @Desc    : 各类榜单

import json
import pandas as pd
import requests


def douban_movie_list():
    """
    豆瓣新片榜
    Returns
    -------
    DataFrame
        "titleCn, title，rate, link, img, description, ranking"
    """
    try:
        url = "https://www.bjsoubang.com/api/getChannelData"
        params = {
            "channel_id": 16
        }
        r = requests.get(url=url, params=params)
        res_list = json.loads(r.text)['info']['data']
        df = pd.DataFrame(res_list)
        df['ranking'] = df.index + 1
        return df
    except:
        return None


def douban_week_praise_list():
    """
    豆瓣一周口碑榜
    Returns
    -------
    DataFrame
        "title，trend, link, ranking"
    """
    try:
        url = "https://www.bjsoubang.com/api/getChannelData"
        params = {
            "channel_id": 19
        }
        r = requests.get(url=url, params=params)
        res_list = json.loads(r.text)['info']['data']
        df = pd.DataFrame(res_list)
        return df
    except:
        return None


def zhihu_hot_search_list():
    """
    知乎热搜榜
    Returns
    -------
    DataFrame
        "display_query，query, link, ranking"
    """
    try:
        url = "https://www.bjsoubang.com/api/getChannelData"
        params = {
            "channel_id": 10
        }
        r = requests.get(url=url, params=params)
        res_list = json.loads(r.text)['info']['data']
        df = pd.DataFrame(res_list)
        df['ranking'] = df.index + 1
        return df
    except:
        return None


def zhihu_hot_list():
    """
    知乎热榜
    Returns
    -------
    DataFrame
        "title, img，description, link, ranking, hot"
    """
    try:
        url = "https://www.bjsoubang.com/api/getChannelData"
        params = {
            "channel_id": 2
        }
        r = requests.get(url=url, params=params)
        res_list = json.loads(r.text)['info']['data']
        df = pd.DataFrame(res_list)
        df['ranking'] = df.index + 1
        return df
    except:
        return None


def wx_hot_word_list():
    """
    微信热词榜
    Returns
    -------
    DataFrame
        "title, link, hot_rank, ranking"
    """
    try:
        url = "https://www.bjsoubang.com/api/getChannelData"
        params = {
            "channel_id": 6
        }
        r = requests.get(url=url, params=params)
        res_list = json.loads(r.text)['info']['data']
        df = pd.DataFrame(res_list)
        df['ranking'] = df.index + 1
        return df
    except:
        return None


def wx_hot_list():
    """
    微信热门榜
    Returns
    -------
    DataFrame
        "title, img，description, link, ranking"
    """
    try:
        url = "https://www.bjsoubang.com/api/getChannelData"
        params = {
            "channel_id": 1
        }
        r = requests.get(url=url, params=params)
        res_list = json.loads(r.text)['info']['data']
        df = pd.DataFrame(res_list)
        df['ranking'] = df.index + 1
        return df
    except:
        return None


def weibo_hot_search_list():
    """
    微博热搜榜
    Returns
    -------
    DataFrame
        "title, tag, link, hot, ranking"
    """
    try:
        url = "https://www.bjsoubang.com/api/getChannelData"
        params = {
            "channel_id": 4
        }
        r = requests.get(url=url, params=params)
        res_list = json.loads(r.text)['info']['data']
        df = pd.DataFrame(res_list)
        df['ranking'] = df.index + 1
        return df
    except:
        return None


def weibo_new_era_list():
    """
    微博新时代榜
    Returns
    -------
    DataFrame
        "title, link, ranking"
    """
    try:
        url = "https://www.bjsoubang.com/api/getChannelData"
        params = {
            "channel_id": 5
        }
        r = requests.get(url=url, params=params)
        res_list = json.loads(r.text)['info']['data']
        df = pd.DataFrame(res_list)
        df['ranking'] = df.index + 1
        return df
    except:
        return None


def baidu_hot_list():
    """
    百度实时热点榜
    Returns
    -------
    DataFrame
        "title, id, status, link_video, link_search, link_news, link_img, hot, ranking"
    """
    try:
        url = "https://www.bjsoubang.com/api/getChannelData"
        params = {
            "channel_id": 3
        }
        r = requests.get(url=url, params=params)
        res_list = json.loads(r.text)['info']['data']
        df = pd.DataFrame(res_list)
        df['ranking'] = df.index + 1
        return df
    except:
        return None


def baidu_today_hot_list():
    """
    百度今日热点榜
    Returns
    -------
    DataFrame
        "title, id, status, link_video, link_search, link_news, link_img, hot, ranking"
    """
    try:
        url = "https://www.bjsoubang.com/api/getChannelData"
        params = {
            "channel_id": 12
        }
        r = requests.get(url=url, params=params)
        res_list = json.loads(r.text)['info']['data']
        df = pd.DataFrame(res_list)
        df['ranking'] = df.index + 1
        return df
    except:
        return None


def baidu_hot_word_list():
    """
    百度百科热词榜
    Returns
    -------
    DataFrame
        "title, link, status, description, ranking"
    """
    try:
        url = "https://www.bjsoubang.com/api/getChannelData"
        params = {
            "channel_id": 9
        }
        r = requests.get(url=url, params=params)
        res_list = json.loads(r.text)['info']['data']
        df = pd.DataFrame(res_list)
        df['ranking'] = df.index + 1
        return df
    except:
        return None


if __name__ == "__main__":
    tmp = weibo_new_era_list()
    print(tmp)




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2021/2/20 0020
# @Author  : justin.郑 3907721@qq.com
# @File    : history_daily.py
# @Desc    : 历史上的今日

import json
import pandas as pd
import requests


def history_daily():
    """
    历史上的今日
    Returns
    -------
    DataFrame
        "year，title, type, link, desc""
    """
    try:
        url = "https://www.bjsoubang.com/api/getHistoryDaily"
        r = requests.get(url=url)
        res_list = json.loads(r.text)['info']
        df = pd.DataFrame(res_list)
        df = df.drop(['cover', 'festival', 'recommend'], axis=1)
        return df
    except:
        return None
 

if __name__ == "__main__":
    tmp = history_daily()
    print(tmp)




"""
GoPup 是基于 Python 的开源金融数据接口库, 目的是实现对金融产品和另类数据从数据采集, 数据清洗到数据下载的工具, 满足金融数据科学家, 数据科学爱好者在数据获取方面的需求.
它的特点是利用 GoPup 获取的是基于可信任数据源发布的原始数据, 广大数据科学家可以利用原始数据进行再加工, 从而得出科学的结论.
"""

"""
百度指数
"""
from gopup.index.index_baidu import (
    baidu_search_index,
    baidu_info_index,
    baidu_media_index,
    baidu_interest_index,
    baidu_gender_index,
    baidu_age_index,
    baidu_atlas_index
)

"""
微博指数
"""
from gopup.index.index_weibo import weibo_index

"""
搜狗指数
"""
from gopup.index.index_sogou import sogou_index

"""
头条指数
"""
from gopup.index.index_toutiao import (
    toutiao_index,
    toutiao_relation,
    toutiao_province,
    toutiao_city,
    toutiao_age,
    toutiao_gender,
    toutiao_interest_category
)


"""
谷歌指数
"""
from gopup.index.index_google import (
    google_index,
    google_fact_check
)


"""
百度迁徙地图接口
"""
from gopup.event.area_baidu import (
    migration_area_baidu,
    migration_scale_baidu
)

"""
历史上的今日接口
"""
from gopup.event.history_daily import history_daily


"""
榜单接口
"""
from gopup.event.hot_list import (
    douban_movie_list,
    douban_week_praise_list,
    zhihu_hot_search_list,
    zhihu_hot_list,
    wx_hot_word_list,
    wx_hot_list,
    weibo_hot_search_list,
    weibo_new_era_list,
    baidu_hot_list,
    baidu_today_hot_list,
    baidu_hot_word_list
)


"""
新型冠状病毒接口
"""
from gopup.event.covid import (
    covid_163,
    covid_dxy,
    covid_baidu,
    covid_hist_city,
    covid_hist_province,
)

"""
中国宏观数据
"""
from gopup.economic.marco_cn import (
    marco_cmlrd,
    get_gdp_quarter,
    get_cpi,
    get_ppi,
    get_pmi,
    get_rrr,
    get_money_supply,
    get_gold_and_foreign_reserves,
    get_industrial_growth,
    get_fiscal_revenue,
    get_consumer_total,
    get_credit_data,
    get_fdi_data
)


"""
利率数据
"""
from gopup.economic.shibor import (
    shibor_data,
    shibor_quote_data,
    shibor_ma_data,
    lpr_data
)

"""
中国油价数据
"""
from gopup.life.oil import (
    energy_oil_hist,
    energy_oil_detail
)

"""
新经济公司
"""
from gopup.fortune.itjuzi import (
    death_company,
    nicorn_company,
    maxima_company
)

"""
商业特许经营信息
"""
from gopup.fortune.franchise import franchise_china


"""
影视数据
"""
from gopup.movie.movie import (
    realtime_boxoffice,
    day_boxoffice,
    day_cinema,
    realtime_tv,
    realtime_show,
    realtime_artist,
    realtime_artist_flow
)


"""
高校数据
"""
from gopup.life.university import (
    university,
    adult_university
)

"""
火车数据
"""
from gopup.life.train import (
    station_name,
    train_time_table
)


"""
微博运营数据
"""
from gopup.mcn.weibo import (
    weibo_user,
    weibo_list
)

"""
中国电竞价值排行榜
"""
from gopup.life.game import (
    player_rank,
    club_rank
)


"""
专业版接口
"""
from gopup.pro.pro_data import (pro_api)

from gopup.utils.utils_pass import (
    set_token,
    get_token
)

"""
达人数据
"""
# from gopup.mcn.star import (star_hot_list, star_market_list)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/11/8 16:58
# @Author  : justin.郑 3907721@qq.com
# @File    : oil.py
# @Desc    : 中国油价

import json
import pandas as pd
import requests


def energy_oil_hist():
    """
    汽柴油历史调价信息
    http://data.eastmoney.com/cjsj/oil_default.html
    :return: 汽柴油历史调价数
    :rtype: pandas.DataFrame
    """
    try:
        url = "http://datacenter.eastmoney.com/api/data/get"
        params = {
            "type": "RPTA_WEB_YJ_BD",
            "sty": "ALL",
            "source": "WEB",
            "p": "1",
            "ps": "5000",
            "st": "dim_date",
            "sr": "-1",
            "var": "OxGINxug",
            "rt": "52861006",
        }
        r = requests.get(url, params=params)
        data_text = r.text
        data_json = json.loads(data_text[data_text.find("{"): -1])
        data_df = pd.DataFrame(data_json["result"]["data"])
        data_df.columns = ["日期", "汽油价格", "柴油价格", "汽油涨幅", "柴油涨幅"]
        return data_df
    except:
        return None


def energy_oil_detail(date="2020-03-19"):
    """
    地区油价
    http://data.eastmoney.com/cjsj/oil_default.html
    :param date:
    :type date: str
    :return: 地区油价
    :rtype: pandas.DataFrame
    """
    try:
        url = "http://datacenter.eastmoney.com/api/data/get"
        params = {
            "type": "RPTA_WEB_YJ_JH",
            "sty": "ALL",
            "source": "WEB",
            "p": "1",
            "ps": "5000",
            "st": "cityname",
            "sr": "1",
            "filter": f'(dim_date="{date}")',
            "var": "todayPriceData",
        }
        r = requests.get(url, params=params)
        data_text = r.text
        data_json = json.loads(data_text[data_text.find("{"): -1])
        data_df = pd.DataFrame(data_json["result"]["data"]).iloc[:, 1:]
        return data_df
    except:
        return None



if __name__ == "__main__":
    # energy_oil_hist_df = energy_oil_hist()
    # print(energy_oil_hist_df)
    energy_oil_detail_df = energy_oil_detail(date="2020-09-19")
    print(energy_oil_detail_df)




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/4/18 16:30
# @Author  : justin.郑 3907721@qq.com
# @File    : rest_agent.py
# @Desc    :

import requests
import pandas as pd
from bs4 import BeautifulSoup
import numpy as np


class RestAgent():
    def __init__(self):
        # request header
        self.user_agent = "Mozilla/5.0 (Windows NT 6.1; WOW64) " \
                     "AppleWebKit/537.36 (KHTML, like Gecko) " \
                     "Chrome/57.0.2987.133 Safari/537.36 "

        # simulate http request
        self.session = requests.Session()
        self.session.headers['User-Agent'] = self.user_agent
        self.session.headers['X-Forwarded-For'] = ':'.join('{0:x}'.format(np.random.randint(0, 2**16 - 1)) for i in range(4)) + ':1'
        self.proxies = None

    def add_headers(self, dict):
        self.session.headers.update(dict)

    def get_cookies(self):
        return self.session.cookies

    def set_proxies(self, proxies):
        self.proxies = proxies

    def do_request(self, url, param = None, method="GET", type="text", encoding = None, json = None, **kwargs):
        if self.proxies is None:
            if method == "GET":
                res = self.session.get(url, params=param, **kwargs)
            else:
                if json is not None:
                    res = self.session.post(url, json=json, **kwargs)
                else:
                    res = self.session.post(url, data=param, **kwargs)
        else:
            if method == "GET":
                res = self.session.get(url, params=param, proxies=self.proxies, **kwargs)
            else:
                if json is not None:
                    res = self.session.post(url, json=json, proxies=self.proxies, **kwargs)
                else:
                    res = self.session.post(url, data=param, proxies=self.proxies, **kwargs)

        if res.status_code != 200:
            return None
        else:

            if encoding is not None:
                res.encoding = encoding

            if type == 'text':
                return res.text
            else:
                return res.content

    def get_aspx_param(self, url):
        html = self.do_request(url)
        bsObj = BeautifulSoup(html, 'html5lib')
        __VIEWSTATE          = bsObj.find('input', {'id': '__VIEWSTATE'}).attrs['value']
        __EVENTVALIDATION    = bsObj.find('input', {'id': '__EVENTVALIDATION'}).attrs['value']
        __VIEWSTATEGENERATOR = bsObj.find('input', {'id' : '__VIEWSTATEGENERATOR'}).attrs['value']

        data = {
            "__VIEWSTATE"            : __VIEWSTATE,
            "__EVENTVALIDATION"     : __EVENTVALIDATION,
            "__VIEWSTATEGENERATOR"  : __VIEWSTATEGENERATOR,
        }
        return data

    def get_proxy_list(self):
        url = "http://www.mimiip.com/gngao/"
        pageno = 0

        proxy_list = []
        while pageno < 10:
            pageno = pageno + 1
            rsp = self.do_request(url + str(pageno), None, None)

            if rsp is None:
                return None

            soup = BeautifulSoup(rsp)
            tables = soup.find_all('table')

            data = []
            for table in tables:
                if table.has_key('class') and "list" in table['class']:
                    rows = table.findAll('tr')
                    for row in rows:
                        cols = row.findAll('td')
                        if (len(cols) > 5) :
                            ip   = cols[0].text
                            port = cols[1].text
                            type = cols[4].text
                            data.append((ip, port, type))

            if len(data) == 0:
                break
            else:
                proxy_list.extend(data)

        df = pd.DataFrame(proxy_list)
        df.columns = ['IP', 'Port', 'Type']

        return df


if __name__ == '__main__':
    aqi = RestAgent()
    result = aqi.get_proxy_list()
    print(result)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/3/20 0020
# @Author  : justin.郑 3907721@qq.com
# @File    : setup.py
# @Desc    : setup

from setuptools import find_packages, setup
import os

URL = 'https://github.com/justinzm/gopup'
NAME = 'gopup'
VERSION = '0.3.8'
DESCRIPTION = 'GoPUP database'
if os.path.exists('README.md'):
    with open('README.md', encoding='utf-8') as f:
        LONG_DESCRIPTION = f.read()
else:
    LONG_DESCRIPTION = DESCRIPTION
AUTHOR = 'Justin ZM'
AUTHOR_EMAIL = '3907721@qq.com'
LICENSE = 'MIT'
PLATFORMS = [
    'all',
]
REQUIRES = [
    'requests',
    'pandas',
    'demjson',
    'jsonpath',
    'bs4',
    'Pillow',
    'matplotlib',
    'xlrd',
    'pyexecjs',
    'pyquery',
    'tqdm',
    'pycryptodome'
]
# CONSOLE_SCRIPT = 'my-cmd=my_pkg.my_cmd:main'
# # 如果想在 pip install 之后自动生成一个可执行命令，就靠它了:
# # <command>=<package_name>.<python_file_name>:<python_function>
# # 值得注意的是：
# # python_file_name 是不能用"-"的，需要用"_"，但 command 可以用"-"
# # my_cmd.py 也很简单，正常写即可，方法名也不一定是 main

# 需要的信息就在 setup() 中加上，不需要的可以不加
setup(
    name=NAME,
    version=VERSION,
    description=(
        DESCRIPTION
    ),
    long_description=LONG_DESCRIPTION,
    long_description_content_type='text/markdown',
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    maintainer=AUTHOR,
    maintainer_email=AUTHOR_EMAIL,
    license=LICENSE,
    packages=find_packages(),
    platforms=PLATFORMS,
    url=URL,
    install_requires=REQUIRES,
    # entry_points={
    #     'console_scripts': [CONSOLE_SCRIPT],
    # }
)




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/10/23 0023
# @Author  : justin.郑 3907721@qq.com
# @File    : index_toutiao.py
# @Desc    : 头条指数

import json
import pandas as pd
import requests
from gopup.index.cons import index_toutiao_headers


def toutiao_index(keyword="python", start_date="20201016", end_date="20201022", app_name="toutiao"):
    """
    头条指数数据
    :param keyword:     关键词
    :param start_date:  开始日期
    :param end_date:    截止日期
    :param app_name:    平台
    :return:
        datetime    日期
        index       指数
    """
    # list_keyword = '["%s"]' % keyword
    try:
        url = "https://trendinsight.oceanengine.com/api/open/index/get_multi_keyword_hot_trend"
        data = {
            "keyword_list": [keyword],
            "start_date": start_date,
            "end_date": end_date,
            "app_name": app_name
        }
        res = requests.post(url, json=data, headers=index_toutiao_headers)
        hot_list = json.loads(res.text)['data']['hot_list'][0]['hot_list']
        df = pd.DataFrame(hot_list)
        return df
    except:
        return None


def toutiao_relation(keyword="python", start_date="20201012", end_date="20201018", app_name="toutiao"):
    """
    头条相关分析
    :param keyword:     关键词
    :param start_date:  开始日期
    :param end_date:    截止日期
    :return:
        relation_word    相关词
        relation_score   相关性值
        score_rank       相关性值排名
        search_hot       搜索热点值
        search_ratio     搜索比率
    """
    try:
        url = "https://trendinsight.oceanengine.com/api/open/index/get_relation_word"
        data = {"param": {"keyword": keyword,
                          "start_date": start_date,
                          "end_date": end_date,
                          "app_name": app_name}
                }
        res = requests.post(url, json=data, headers=index_toutiao_headers)
        relation_word_list = json.loads(res.text)['data']['relation_word_list']
        df = pd.DataFrame(relation_word_list)
        return df
    except:
        return None


# def toutiao_sentiment(keyword="python", start_date="20201012", end_date="20201018"):
#     """
#     头条情感分析
#     :param keyword:     关键词
#     :param start_date:  开始日期
#     :param end_date:    截止日期
#     :return:
#         keyword    关键词
#         score      情感值
#     """
#     url = "https://index.toutiao.com/api/v1/get_keyword_sentiment"
#     data = {
#         "keyword": keyword,
#         "start_date": start_date,
#         "end_date": end_date
#     }
#     res = requests.get(url, params=data, headers=index_toutiao_headers)
#     score = json.loads(res.text)['data']['score']
#     df = pd.DataFrame([{"score": score, "keyword": keyword}])
#     return df


def toutiao_province(keyword="python", start_date="20201012", end_date="20201018", app_name="toutiao"):
    """
    头条地域分析
    :param keyword:     关键词
    :param start_date:  开始日期
    :param end_date:    截止日期
    :return:
        name    省份
        value   渗透率
    """
    try:
        url = "https://trendinsight.oceanengine.com/api/open/index/get_portrait"
        data = {"param": {"keyword": keyword,
                          "start_date": start_date,
                          "end_date": end_date,
                          "app_name": app_name}
                }
        res = requests.post(url, json=data, headers=index_toutiao_headers)
        res_text = json.loads(res.text)['data']['data'][2]['label_list']
        df = pd.DataFrame(res_text)
        df['name'] = df['name_zh']
        df = df.drop(['label_id', 'name_zh'], axis=1)
        df = df.sort_values(by="value", ascending=False)
        return df
    except:
        return None

def toutiao_city(keyword="python", start_date="20201012", end_date="20201018", app_name="toutiao"):
    """
    头条城市分析
    :param keyword:     关键词
    :param start_date:  开始日期
    :param end_date:    截止日期
    :return:
        name    城市
        value   渗透率
    """
    try:
        url = "https://trendinsight.oceanengine.com/api/open/index/get_portrait"
        data = {"param": {"keyword": keyword,
                          "start_date": start_date,
                          "end_date": end_date,
                          "app_name": app_name}
                }
        res = requests.post(url, json=data, headers=index_toutiao_headers)
        res_text = json.loads(res.text)['data']['data'][3]['label_list']
        df = pd.DataFrame(res_text)
        df['name'] = df['name_zh']
        df = df.drop(['label_id', 'name_zh'], axis=1)
        df = df.sort_values(by="value", ascending=False)
        return df
    except:
        return None


def toutiao_age(keyword="python", start_date="20201012", end_date="20201018", app_name="toutiao"):
    """
    头条年龄分析
    :param keyword:     关键词
    :param start_date:  开始日期
    :param end_date:    截止日期
    :return:
        name    年龄区间
        value   渗透率
    """
    try:
        url = "https://trendinsight.oceanengine.com/api/open/index/get_portrait"
        data = {"param": {"keyword": keyword,
                         "start_date": start_date,
                         "end_date": end_date,
                         "app_name": app_name}
                }
        res = requests.post(url, json=data, headers=index_toutiao_headers)
        res_text = json.loads(res.text)['data']['data'][0]['label_list']
        df = pd.DataFrame(res_text)
        df['name'] = df['name_zh']
        df = df.drop(['label_id', 'name_zh'], axis=1)
        return df
    except:
        return None


def toutiao_gender(keyword="python", start_date="20201012", end_date="20201018", app_name="toutiao"):
    """
    头条性别分析
    :param keyword:     关键词
    :param start_date:  开始日期
    :param end_date:    截止日期
    :return:
        name    性别
        value   渗透率
    """
    try:
        url = "https://trendinsight.oceanengine.com/api/open/index/get_portrait"
        data = {"param": {"keyword": keyword,
                          "start_date": start_date,
                          "end_date": end_date,
                          "app_name": app_name}
                }
        res = requests.post(url, json=data, headers=index_toutiao_headers)
        res_text = json.loads(res.text)['data']['data'][1]['label_list']
        df = pd.DataFrame(res_text)
        df['name'] = df['name_zh']
        df = df.drop(['label_id', 'name_zh'], axis=1)
        df = df.sort_values(by="value", ascending=False)
        return df
    except:
        return None


def toutiao_interest_category(keyword="python", start_date="20201012", end_date="20201018", app_name="toutiao"):
    """
    头条用户阅读兴趣分类
    :param keyword:     关键词
    :param start_date:  开始日期
    :param end_date:    截止日期
    :return:
        name    分类
        value   渗透率
    """
    try:
        url = "https://trendinsight.oceanengine.com/api/open/index/get_portrait"
        data = {"param": {"keyword": keyword,
                          "start_date": start_date,
                          "end_date": end_date,
                          "app_name": app_name}
                }
        res = requests.post(url, json=data, headers=index_toutiao_headers)
        res_text = json.loads(res.text)['data']['data'][4]['label_list']
        df = pd.DataFrame(res_text)
        df['name'] = df['name_zh']
        df = df.drop(['label_id', 'name_zh'], axis=1)
        df = df.sort_values(by="value", ascending=False)
        return df
    except:
        return None


if __name__ == "__main__":
    index_df = toutiao_index(keyword="茅台", start_date='20211231', end_date='20211231', app_name="toutiao")
    print(index_df)
 




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2021/5/15 17:26
# @Author  : justin.郑 3907721@qq.com
# @File    : game.py
# @Desc    : 游戏排行榜

import requests
import time
import pandas as pd
from pyquery import PyQuery as pq


def club_rank(type):
    """
    中国电竞价值排行榜 俱乐部排行榜
    Parameters
    ------
      type: 类型    gameid
            英雄联盟 2
            绝地求生 3
            王者荣耀 4
            DOTA2  1
            穿越火线 5
            和平精英 6
    Return
    ------
    日期、类型、排名、俱乐部logo、俱乐部名称、人气指数、舆论指数、综合指数、排名变动

    http://rank.uuu9.com/club/ranking?gameId=6&type=0
    """
    if type == "DOTA2":
        gameid = 1
    elif type == "英雄联盟":
        gameid = 2
    elif type == "绝地求生":
        gameid = 3
    elif type == "王者荣耀":
        gameid = 4
    elif type == "穿越火线":
        gameid = 5
    elif type == "和平精英":
        gameid = 6
    else:
        return "游戏名称输入错误"
    try:
        url = "http://rank.uuu9.com/club/ranking?gameId=%s&type=0" % gameid
        herder = {
            "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
            "Accept-Language": "zh-CN,zh;q=0.8,en-US;q=0.5,en;q=0.3",
            "Accept-Encoding": "gzip, deflate",
            "Connection": "keep-alive"
        }
        r = requests.get(url=url, headers=herder)
        doc = pq(r.text)
        trs = doc(".ec_table table tbody tr")
        res_list= []
        for tr in trs.items():
            bd_res = tr(".ec_change i").attr("class")
            bd_val = tr(".ec_change").text()
            if bd_res == "rise":
                bd = "上升 %s位" % bd_val
            elif bd_res == "decline":
                bd = "下降 %s位" % bd_val
            else:
                bd = "-"
            res_dict = {
                "日期": time.strftime("%Y-%m-%d"),
                "类型": type,
                "排名": tr.find(".ec_num").text(),
                "俱乐部logo": "http://rank.uuu9.com/%s" % tr("img").attr("src"),
                "俱乐部名称": tr("dd").text(),
                "人气指数": tr("td:nth-child(3)").text(),
                "舆论指数": tr("td:nth-child(4)").text(),
                "综合指数": tr("td:nth-child(5)").text(),
                "排名变动": bd
            }
            res_list.append(res_dict)
        res_pd = pd.DataFrame(res_list)
        return res_pd
    except:
        return None


def player_rank(type):
    """
    中国电竞价值排行榜 选手排行榜
    Parameters
    ------
      type: 类型    gameid
            英雄联盟 2
            绝地求生 3
            王者荣耀 4
            DOTA2  1
            穿越火线 5
            和平精英 6
    Return
    ------
    日期、类型、排名、选手头像、选手名、所属战队、人气指数、舆论指数、战绩指数、综合指数、身价、排名变动

    http://rank.uuu9.com/player/ranking?gameId=6&type=0
    """
    if type == "DOTA2":
        gameid = 1
    elif type == "英雄联盟":
        gameid = 2
    elif type == "绝地求生":
        gameid = 3
    elif type == "王者荣耀":
        gameid = 4
    elif type == "穿越火线":
        gameid = 5
    elif type == "和平精英":
        gameid = 6
    else:
        return "游戏名称输入错误"
    try:
        url = "http://rank.uuu9.com/player/ranking?gameId=%s&type=0" % gameid
        herder = {
            "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
            "Accept-Language": "zh-CN,zh;q=0.8,en-US;q=0.5,en;q=0.3",
            "Accept-Encoding": "gzip, deflate",
            "Connection": "keep-alive"
        }
        r = requests.get(url=url, headers=herder)
        doc = pq(r.text)
        trs = doc(".ec_table table tbody tr")
        res_list= []
        for tr in trs.items():
            bd_res = tr(".ec_change i").attr("class")
            bd_val = tr(".ec_change").text()
            if bd_res == "rise":
                bd = "上升 %s位" % bd_val
            elif bd_res == "decline":
                bd = "下降 %s位" % bd_val
            else:
                bd = "-"
            if type == "英雄联盟":
                res_dict = {
                    "日期": time.strftime("%Y-%m-%d"),
                    "类型": type,
                    "排名": tr.find(".ec_num").text(),
                    "选手头像": "http://rank.uuu9.com/%s" % tr("img").attr("src"),
                    "选手名": tr("dd").text(),
                    "所属战队": tr("td:nth-child(3)").text(),
                    "人气指数": tr("td:nth-child(4)").text(),
                    "舆论指数": tr("td:nth-child(5)").text(),
                    "战绩指数": tr("td:nth-child(6)").text(),
                    "综合指数": tr("td:nth-child(7)").text(),
                    "身价": tr("td:nth-child(8)").text(),
                    "排名变动": bd
                }
            else:
                res_dict = {
                    "日期": time.strftime("%Y-%m-%d"),
                    "类型": type,
                    "排名": tr.find(".ec_num").text(),
                    "选手头像": "http://rank.uuu9.com/%s" % tr("img").attr("src"),
                    "选手名": tr("dd").text(),
                    "所属战队": tr("td:nth-child(3)").text(),
                    "人气指数": tr("td:nth-child(4)").text(),
                    "舆论指数": tr("td:nth-child(5)").text(),
                    "综合指数": tr("td:nth-child(6)").text(),
                    "身价": tr("td:nth-child(7)").text(),
                    "排名变动": bd
                }

            res_list.append(res_dict)
        res_pd = pd.DataFrame(res_list)
        return res_pd
    except:
        return None


if __name__ == "__main__":
    tmp = player_rank(type="英雄联盟")
    print(tmp)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/10/23 0023
# @Author  : justin.郑 3907721@qq.com
# @File    : google_request.py
# @Desc    :

import json
import pandas as pd
import requests
from urllib.parse import quote
import copy
from typing import Optional
from urllib3 import Retry


class TrendReq(object):
    """
    Google Trends API
    """

    GET_METHOD = "get"
    POST_METHOD = "post"
    GENERAL_URL = "https://trends.google.com/trends/api/explore"
    INTEREST_OVER_TIME_URL = "https://trends.google.com/trends/api/widgetdata/multiline"
    INTEREST_BY_REGION_URL = (
        "https://trends.google.com/trends/api/widgetdata/comparedgeo"
    )
    RELATED_QUERIES_URL = (
        "https://trends.google.com/trends/api/widgetdata/relatedsearches"
    )
    TRENDING_SEARCHES_URL = (
        "https://trends.google.com/trends/hottrends/visualize/internal/data"
    )
    TOP_CHARTS_URL = "https://trends.google.com/trends/api/topcharts"
    SUGGESTIONS_URL = "https://trends.google.com/trends/api/autocomplete/"
    CATEGORIES_URL = "https://trends.google.com/trends/api/explore/pickers/category"
    TODAY_SEARCHES_URL = "https://trends.google.com/trends/api/dailytrends"

    def __init__(
        self,
        hl="en-US",
        tz=360,
        geo="",
        timeout=(2, 5),
        proxies="",
        retries=0,
        backoff_factor=0,
    ):
        """
        Initialize default values for params
        """
        # google rate limit
        self.google_rl = "You have reached your quota limit. Please try again later."
        self.results = None
        # set user defined options used globally
        self.tz = tz
        self.hl = hl
        self.geo = geo
        self.kw_list = list()
        self.timeout = timeout
        self.proxies = proxies  # add a proxy option
        self.retries = retries
        self.backoff_factor = backoff_factor
        self.proxy_index = 0
        self.cookies = self.GetGoogleCookie()
        # intialize widget payloads
        self.token_payload = dict()
        self.interest_over_time_widget = dict()
        self.interest_by_region_widget = dict()
        self.related_topics_widget_list = list()
        self.related_queries_widget_list = list()

    def GetGoogleCookie(self):
        """
        Gets google cookie (used for each and every proxy; once on init otherwise)
        Removes proxy from the list on proxy error
        """
        while True:
            if len(self.proxies) > 0:
                proxy = {"https": self.proxies[self.proxy_index]}
            else:
                proxy = ""
            try:
                return dict(
                    filter(
                        lambda i: i[0] == "NID",
                        requests.get(
                            "https://trends.google.com/?geo={geo}".format(
                                geo=self.hl[-2:]
                            ),
                            timeout=self.timeout,
                            proxies=proxy,
                        ).cookies.items(),
                    )
                )
            except requests.exceptions.ProxyError:
                print("Proxy error. Changing IP")
                if len(self.proxies) > 0:
                    self.proxies.remove(self.proxies[self.proxy_index])
                else:
                    print("Proxy list is empty. Bye!")
                continue

    def GetNewProxy(self):
        """
        Increment proxy INDEX; zero on overflow
        """
        if self.proxy_index < (len(self.proxies) - 1):
            self.proxy_index += 1
        else:
            self.proxy_index = 0

    def _get_data(self, url, method=GET_METHOD, trim_chars=0, **kwargs):
        """Send a request to Google and return the JSON response as a Python object
        :param url: the url to which the request will be sent
        :param method: the HTTP method ('get' or 'post')
        :param trim_chars: how many characters should be trimmed off the beginning of the content of the response
            before this is passed to the JSON parser
        :param kwargs: any extra key arguments passed to the request builder (usually query parameters or data)
        :return:
        """
        s = requests.session()
        # Retries mechanism. Activated when one of statements >0 (best used for proxy)
        if self.retries > 0 or self.backoff_factor > 0:
            retry = Retry(
                total=self.retries,
                read=self.retries,
                connect=self.retries,
                backoff_factor=self.backoff_factor,
            )

        s.headers.update({"accept-language": self.hl})
        if len(self.proxies) > 0:
            self.cookies = self.GetGoogleCookie()
            s.proxies.update({"https": self.proxies[self.proxy_index]})
        if method == TrendReq.POST_METHOD:
            response = s.post(
                url, timeout=self.timeout, cookies=self.cookies, **kwargs
            )  # DO NOT USE retries or backoff_factor here
        else:
            response = s.get(
                url, timeout=self.timeout, cookies=self.cookies, **kwargs
            )  # DO NOT USE retries or backoff_factor here
        # check if the response contains json and throw an exception otherwise
        # Google mostly sends 'application/json' in the Content-Type header,
        # but occasionally it sends 'application/javascript
        # and sometimes even 'text/javascript
        if (
            response.status_code == 200
            and "application/json" in response.headers["Content-Type"]
            or "application/javascript" in response.headers["Content-Type"]
            or "text/javascript" in response.headers["Content-Type"]
        ):
            # trim initial characters
            # some responses start with garbage characters, like ")]}',"
            # these have to be cleaned before being passed to the json parser
            content = response.text[trim_chars:]
            # parse json
            self.GetNewProxy()
            return json.loads(content)
        else:
            # error
            # raise "The request failed: Google returned a ……"
            print("The request failed: Google returned a ……")

    def build_payload(self, kw_list, cat=0, timeframe="today 5-y", geo="", gprop=""):
        """Create the payload for related queries, interest over time and interest by region"""
        self.kw_list = kw_list
        self.geo = geo or self.geo
        self.token_payload = {
            "hl": self.hl,
            "tz": self.tz,
            "req": {"comparisonItem": [], "category": cat, "property": gprop},
        }

        # build out json for each keyword
        for kw in self.kw_list:
            keyword_payload = {"keyword": kw, "time": timeframe, "geo": self.geo}
            self.token_payload["req"]["comparisonItem"].append(keyword_payload)
        # requests will mangle this if it is not a string
        self.token_payload["req"] = json.dumps(self.token_payload["req"])
        # get tokens
        self._tokens()
        return

    def _tokens(self):
        """Makes request to Google to get API tokens for interest over time, interest by region and related queries"""
        # make the request and parse the returned json
        widget_dict = self._get_data(
            url=TrendReq.GENERAL_URL,
            method=TrendReq.GET_METHOD,
            params=self.token_payload,
            trim_chars=4,
        )["widgets"]
        # order of the json matters...
        first_region_token = True
        # clear self.related_queries_widget_list and self.related_topics_widget_list
        # of old keywords'widgets
        self.related_queries_widget_list[:] = []
        self.related_topics_widget_list[:] = []
        # assign requests
        for widget in widget_dict:
            if widget["id"] == "TIMESERIES":
                self.interest_over_time_widget = widget
            if widget["id"] == "GEO_MAP" and first_region_token:
                self.interest_by_region_widget = widget
                first_region_token = False
            # response for each term, put into a list
            if "RELATED_TOPICS" in widget["id"]:
                self.related_topics_widget_list.append(widget)
            if "RELATED_QUERIES" in widget["id"]:
                self.related_queries_widget_list.append(widget)
        return

    def interest_over_time(self):
        """Request data from Google's Interest Over Time section and return a dataframe"""

        over_time_payload = {
            # convert to string as requests will mangle
            "req": json.dumps(self.interest_over_time_widget["request"]),
            "token": self.interest_over_time_widget["token"],
            "tz": self.tz,
        }

        # make the request and parse the returned json
        req_json = self._get_data(
            url=TrendReq.INTEREST_OVER_TIME_URL,
            method=TrendReq.GET_METHOD,
            trim_chars=5,
            params=over_time_payload,
        )

        df = pd.DataFrame(req_json["default"]["timelineData"])
        if df.empty:
            return df

        df["date"] = pd.to_datetime(df["time"].astype(dtype="float64"), unit="s")
        df = df.set_index(["date"]).sort_index()
        # split list columns into separate ones, remove brackets and split on comma
        result_df = df["value"].apply(
            lambda x: pd.Series(str(x).replace("[", "").replace("]", "").split(","))
        )
        # rename each column with its search term, relying on order that google provides...
        for idx, kw in enumerate(self.kw_list):
            # there is currently a bug with assigning columns that may be
            # parsed as a date in pandas: use explicit insert column method
            result_df.insert(len(result_df.columns), kw, result_df[idx].astype("int"))
            del result_df[idx]

        if "isPartial" in df:
            # make other dataframe from isPartial key data
            # split list columns into separate ones, remove brackets and split on comma
            df = df.fillna(False)
            result_df2 = df["isPartial"].apply(
                lambda x: pd.Series(str(x).replace("[", "").replace("]", "").split(","))
            )
            result_df2.columns = ["isPartial"]
            # concatenate the two dataframes
            final = pd.concat([result_df, result_df2], axis=1)
        else:
            final = result_df
            final["isPartial"] = False

        return final

    def interest_by_region(
        self, resolution="COUNTRY", inc_low_vol=False, inc_geo_code=False
    ):
        """Request data from Google's Interest by Region section and return a dataframe"""

        # make the request
        region_payload = dict()
        if self.geo == "":
            self.interest_by_region_widget["request"]["resolution"] = resolution
        elif self.geo == "US" and resolution in ["DMA", "CITY", "REGION"]:
            self.interest_by_region_widget["request"]["resolution"] = resolution

        self.interest_by_region_widget["request"][
            "includeLowSearchVolumeGeos"
        ] = inc_low_vol

        # convert to string as requests will mangle
        region_payload["req"] = json.dumps(self.interest_by_region_widget["request"])
        region_payload["token"] = self.interest_by_region_widget["token"]
        region_payload["tz"] = self.tz

        # parse returned json
        req_json = self._get_data(
            url=TrendReq.INTEREST_BY_REGION_URL,
            method=TrendReq.GET_METHOD,
            trim_chars=5,
            params=region_payload,
        )
        df = pd.DataFrame(req_json["default"]["geoMapData"])
        if df.empty:
            return df

        # rename the column with the search keyword
        df = df[["geoName", "geoCode", "value"]].set_index(["geoName"]).sort_index()
        # split list columns into separate ones, remove brackets and split on comma
        result_df = df["value"].apply(
            lambda x: pd.Series(str(x).replace("[", "").replace("]", "").split(","))
        )
        if inc_geo_code:
            result_df["geoCode"] = df["geoCode"]

        # rename each column with its search term
        for idx, kw in enumerate(self.kw_list):
            result_df[kw] = result_df[idx].astype("int")
            del result_df[idx]

        return result_df

    def related_topics(self):
        """Request data from Google's Related Topics section and return a dictionary of dataframes

        If no top and/or rising related topics are found, the value for the key "top" and/or "rising" will be None
        """

        # make the request
        related_payload = dict()
        result_dict = dict()
        for request_json in self.related_topics_widget_list:
            # ensure we know which keyword we are looking at rather than relying on order
            kw = request_json["request"]["restriction"]["complexKeywordsRestriction"][
                "keyword"
            ][0]["value"]
            # convert to string as requests will mangle
            related_payload["req"] = json.dumps(request_json["request"])
            related_payload["token"] = request_json["token"]
            related_payload["tz"] = self.tz

            # parse the returned json
            req_json = self._get_data(
                url=TrendReq.RELATED_QUERIES_URL,
                method=TrendReq.GET_METHOD,
                trim_chars=5,
                params=related_payload,
            )

            # top topics
            try:
                top_list = req_json["default"]["rankedList"][0]["rankedKeyword"]
                df_top = pd.DataFrame([nested_to_record(d, sep="_") for d in top_list])
            except KeyError:
                # in case no top topics are found, the lines above will throw a KeyError
                df_top = None

            # rising topics
            try:
                rising_list = req_json["default"]["rankedList"][1]["rankedKeyword"]
                df_rising = pd.DataFrame(
                    [nested_to_record(d, sep="_") for d in rising_list]
                )
            except KeyError:
                # in case no rising topics are found, the lines above will throw a KeyError
                df_rising = None

            result_dict[kw] = {"rising": df_rising, "top": df_top}
        return result_dict

    def related_queries(self):
        """Request data from Google's Related Queries section and return a dictionary of dataframes

        If no top and/or rising related queries are found, the value for the key "top" and/or "rising" will be None
        """

        # make the request
        related_payload = dict()
        result_dict = dict()
        for request_json in self.related_queries_widget_list:
            # ensure we know which keyword we are looking at rather than relying on order
            kw = request_json["request"]["restriction"]["complexKeywordsRestriction"][
                "keyword"
            ][0]["value"]
            # convert to string as requests will mangle
            related_payload["req"] = json.dumps(request_json["request"])
            related_payload["token"] = request_json["token"]
            related_payload["tz"] = self.tz

            # parse the returned json
            req_json = self._get_data(
                url=TrendReq.RELATED_QUERIES_URL,
                method=TrendReq.GET_METHOD,
                trim_chars=5,
                params=related_payload,
            )

            # top queries
            try:
                top_df = pd.DataFrame(
                    req_json["default"]["rankedList"][0]["rankedKeyword"]
                )
                top_df = top_df[["query", "value"]]
            except KeyError:
                # in case no top queries are found, the lines above will throw a KeyError
                top_df = None

            # rising queries
            try:
                rising_df = pd.DataFrame(
                    req_json["default"]["rankedList"][1]["rankedKeyword"]
                )
                rising_df = rising_df[["query", "value"]]
            except KeyError:
                # in case no rising queries are found, the lines above will throw a KeyError
                rising_df = None

            result_dict[kw] = {"top": top_df, "rising": rising_df}
        return result_dict

    def trending_searches(self, pn="united_states"):
        """Request data from Google's Hot Searches section and return a dataframe"""

        # make the request
        # forms become obsolute due to the new TRENDING_SEACHES_URL
        # forms = {'ajax': 1, 'pn': pn, 'htd': '', 'htv': 'l'}
        req_json = self._get_data(
            url=TrendReq.TRENDING_SEARCHES_URL, method=TrendReq.GET_METHOD
        )[pn]
        result_df = pd.DataFrame(req_json)
        return result_df

    def today_searches(self, pn="US"):
        """Request data from Google Daily Trends section and returns a dataframe"""
        forms = {"ns": 15, "geo": pn, "tz": "-180", "hl": "en-US"}
        req_json = self._get_data(
            url=TrendReq.TODAY_SEARCHES_URL,
            method=TrendReq.GET_METHOD,
            trim_chars=5,
            params=forms,
        )["default"]["trendingSearchesDays"][0]["trendingSearches"]
        result_df = pd.DataFrame()
        # parse the returned json
        sub_df = pd.DataFrame()
        for trend in req_json:
            sub_df = sub_df.append(trend["title"], ignore_index=True)
        result_df = pd.concat([result_df, sub_df])
        return result_df.iloc[:, -1]

    def top_charts(self, date, hl="en-US", tz=300, geo="GLOBAL"):
        """Request data from Google's Top Charts section and return a dataframe"""
        # create the payload
        chart_payload = {
            "hl": hl,
            "tz": tz,
            "date": date,
            "geo": geo,
            "isMobile": False,
        }

        # make the request and parse the returned json
        req_json = self._get_data(
            url=TrendReq.TOP_CHARTS_URL,
            method=TrendReq.GET_METHOD,
            trim_chars=5,
            params=chart_payload,
        )["topCharts"][0]["listItems"]
        df = pd.DataFrame(req_json)
        return df

    def suggestions(self, keyword):
        """Request data from Google's Keyword Suggestion dropdown and return a dictionary"""

        # make the request
        kw_param = quote(keyword)
        parameters = {"hl": self.hl}

        req_json = self._get_data(
            url=TrendReq.SUGGESTIONS_URL + kw_param,
            params=parameters,
            method=TrendReq.GET_METHOD,
            trim_chars=5,
        )["default"]["topics"]
        return req_json

    def categories(self):
        """Request available categories data from Google's API and return a dictionary"""

        params = {"hl": self.hl}

        req_json = self._get_data(
            url=TrendReq.CATEGORIES_URL,
            params=params,
            method=TrendReq.GET_METHOD,
            trim_chars=5,
        )
        return req_json

    def get_historical_interest(
        self,
        keywords,
        year_start=2018,
        month_start=1,
        day_start=1,
        hour_start=0,
        year_end=2018,
        month_end=2,
        day_end=1,
        hour_end=0,
        cat=0,
        geo="",
        gprop="",
        sleep=0,
    ):
        """Gets historical hourly data for interest by chunking requests to 1 week at a time (which is what Google allows)"""

        # construct datetime obejcts - raises ValueError if invalid parameters
        initial_start_date = start_date = datetime(
            year_start, month_start, day_start, hour_start
        )
        end_date = datetime(year_end, month_end, day_end, hour_end)

        # the timeframe has to be in 1 week intervals or Google will reject it
        delta = timedelta(days=7)

        df = pd.DataFrame()

        date_iterator = start_date
        date_iterator += delta

        while True:
            # format date to comply with API call

            start_date_str = start_date.strftime("%Y-%m-%dT%H")
            date_iterator_str = date_iterator.strftime("%Y-%m-%dT%H")

            tf = start_date_str + " " + date_iterator_str

            try:
                self.build_payload(keywords, cat, tf, geo, gprop)
                week_df = self.interest_over_time()
                df = df.append(week_df)
            except Exception as e:
                print(e)
                pass

            start_date += delta
            date_iterator += delta

            if date_iterator > end_date:
                # Run for 7 more days to get remaining data that would have been truncated if we stopped now
                # This is needed because google requires 7 days yet we may end up with a week result less than a full week
                start_date_str = start_date.strftime("%Y-%m-%dT%H")
                date_iterator_str = date_iterator.strftime("%Y-%m-%dT%H")

                tf = start_date_str + " " + date_iterator_str

                try:
                    self.build_payload(keywords, cat, tf, geo, gprop)
                    week_df = self.interest_over_time()
                    df = df.append(week_df)
                except Exception as e:
                    print(e)
                    pass
                break

            # just in case you are rate-limited by Google. Recommended is 60 if you are.
            if sleep > 0:
                time.sleep(sleep)

        # Return the dataframe with results from our timeframe
        return df.loc[initial_start_date:end_date]


def nested_to_record(
    ds,
    prefix: str = "",
    sep: str = ".",
    level: int = 0,
    max_level: Optional[int] = None,
):
    """
    """
    singleton = False
    if isinstance(ds, dict):
        ds = [ds]
        singleton = True
    new_ds = []
    for d in ds:
        new_d = copy.deepcopy(d)
        for k, v in d.items():
            # each key gets renamed with prefix
            if not isinstance(k, str):
                k = str(k)
            if level == 0:
                newkey = k
            else:
                newkey = prefix + sep + k

            # flatten if type is dict and
            # current dict level  < maximum level provided and
            # only dicts gets recurse-flattened
            # only at level>1 do we rename the rest of the keys
            if not isinstance(v, dict) or (
                max_level is not None and level >= max_level
            ):
                if level != 0:  # so we skip copying for top level, common case
                    v = new_d.pop(k)
                    new_d[newkey] = v
                continue
            else:
                v = new_d.pop(k)
                new_d.update(nested_to_record(v, newkey, sep, level + 1, max_level))
        new_ds.append(new_d)

    if singleton:
        return new_ds[0]
    return new_ds


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/10/28 0028
# @Author  : justin.郑 3907721@qq.com
# @File    : university.py
# @Desc    : 高校数据

import json
import pandas as pd
import requests


def university():
    """
    获取全国普通高等学校名单
    :return:
        DataFrame
              序号
              学校名称
              学校标识码
              主管部门
              所在省市
              所在地
              办学层次
              备注
    """
    try:
        url = "http://img.kekepu.com/gaoxiao.json"
        r = requests.get(url=url)
        datas = json.loads(r.text)
        res_list = []
        for data in datas:
            for d in datas[data]:
                tmp = {}
                tmp['序号'] = d['序号']
                tmp['学校名称'] = d['学校名称']
                tmp['学校标识码'] = d['学校标识码']
                tmp['主管部门'] = d['主管部门']
                tmp['所在省市'] = data
                tmp['所在地'] = d['所在地']
                tmp['办学层次'] = d['办学层次']
                tmp['备注'] = d['备注']
                res_list.append(tmp)

        res_pd = pd.DataFrame(res_list)
        return res_pd
    except Exception as e:
        return None


def adult_university():
    """
    获取全国成人高等学校名单
    :return:
        DataFrame
              序号
              学校名称
              学校标识码
              主管部门
              备注
    """
    try:
        url = "adult.xls"
        res_pd = pd.read_excel(url)
        return res_pd
    except Exception as e:
        return None


if __name__ == "__main__":
    tmp = adult_university()
    print(tmp)



 




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/3/29 17:31
# @Author  : justin.郑 3907721@qq.com
# @File    : classifying.py
# @Desc    : 股票分类数据接口

import pandas as pd


def get_industry_classified(standard='sina'):
    """
        获取行业分类数据
    Parameters
    ----------
    standard
    sina:新浪行业 sw：申万 行业

    Returns
    -------
    DataFrame
        code :股票代码
        name :股票名称
        c_name :行业名称
    """
    try:
        if standard == 'sw':
            df = pd.read_csv('http://img.kekepu.com/industry_sw.csv',
                             dtype={'code': object})
        else:
            df = pd.read_csv('http://img.kekepu.com/industry.csv',
                             dtype={'code': object})
        return df
    except:
        return None


def get_concept_classified():
    """
        获取概念分类数据
    Return
    --------
    DataFrame
        code :股票代码
        name :股票名称
        c_name :概念名称
    """
    try:
        df = pd.read_csv('http://img.kekepu.com/concept.csv',
                        dtype={'code': object})
        return df
    except:
        return None

if __name__ == "__main__":
    tmp = get_concept_classified()
    print(tmp)

